@@ -3,6 +3,11 @@ OC.L10N.register(
     {
     "Calendar" : "Calendari",
     "%s has published the calendar \"%s\"" : "%s ha publicat el calendari \"%s\"",
+    "Too many redirects. Aborting ..." : "Massa redireccions. Avortant...",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remot no ens a permès l'accés al calendari  (error HTTP {%s})",
+    "Error connecting to remote server" : "S'ha produit un error al connectar al servidor remot",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error al sol·licitar el recurs al servidor remot. Es possible que estigui relacionat amb un problema amb el certificat",
+    "Error requesting resource on remote server" : "Error al sol·licitar el recurs al servidor remot",
     "Individual" : "Individual",
     "Group" : "Grup",
     "Resource" : "Recurs",
@@ -11,9 +16,15 @@ OC.L10N.register(
     "Required" : "Requerit",
     "Optional" : "Opcional",
     "Does not attend" : "No assistir",
+    "{name} ({email})" : "{name} ({email})",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Et trobes a una zona horaria desconeguda ({tz}), tornant a UTC",
     "Please create a calendar first." : "Si us plau, creeu un calendari primer",
     "New event" : "Esdeveniment nou",
+    "CalDAV address for clients" : "Adreça CalDAV per els clients",
+    "Error saving WebCal-calendar" : "Error desant el calendari WebCal",
+    "WebDAV address for subscriptions" : "Adreça WebDAV per subscripcions",
     "EMail has been sent." : "S'ha enviat el correu.",
+    "There was an issue while sending your EMail." : "S'ha produït un problema al enviar el correu electrònic",
     "group" : "grup",
     "Details" : "Detalls",
     "Attendees" : "Assistents",
@@ -23,6 +34,7 @@ OC.L10N.register(
     "When shared show only busy" : "Mostra només ocupat al compartir",
     "When shared hide this event" : "Ocular aquest esdeveniment al compartir",
     "Confirmed" : "Confirmada",
+    "Tentative" : "Temptativa",
     "Cancelled" : "S'ha cancel·lat",
     "Please add a title!" : "Si us plau, afegiu un títol!",
     "Please select a calendar!" : "Si us plau, seleccioneu un calendari!",
@@ -83,6 +95,8 @@ OC.L10N.register(
     "Event status" : "Estat de l'esdeveniment",
     "Export" : "Exporta",
     "Hello," : "Hola,",
+    "Click here to access it" : "Click aquí per accedir",
+    "Cheers!" : "Salut!",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa d'un error (bug) de \"upstrem\", el calendari no suporta la funció \"asset pipeline\"",
     "Day" : "Dia",
     "Week" : "Setmana",
@@ -93,14 +107,19 @@ OC.L10N.register(
     "More" : "Més",
     "Edit" : "Edita",
     "Link" : "Enllaç",
+    "iCal link" : "iCal link",
     "Download" : "Descàrrega",
+    "Share with users or groups" : "Comparteix amb usuaris o grups",
     "can edit" : "pot editar",
     "Share link" : "Comparteix l'enllaç",
     "Public access" : "Accés públic",
+    "Email link to person" : "Enllaç per correu electrónic amb la persona",
     "Send" : "Envia",
     "New Calendar" : "Calendari nou",
     "Name" : "Nom",
     "New Subscription" : "Nova subscripció",
+    "Go back" : "Tornar enrere",
+    "Go forward" : "Anar endavant",
     "Edit event" : "Edita l'esdeveniment",
     "Delete Event" : "Esborra l'esdeveniment",
     "Save Event" : "Desa l'esdeveniment",
@@ -117,10 +136,14 @@ OC.L10N.register(
     "to" : "a",
     "Repeat every ..." : "Repeteix cada ...",
     "end repeat ..." : "finalitza repetició ...",
+    "times" : "Temps",
     "Import Calendars" : "Importa Calendaris",
+    "Import canceled" : "Importació cancel·lada",
+    "Analyzing calendar" : "Analitzant calendari",
     "New calendar" : "Calendari nou",
-    "Settings" : "configuració",
+    "File is empty" : "El Fitxer està plè",
     "Import calendar" : "Importa calendari",
+    "No Calendars selected for import" : "No heu sel·leccionat cap calendari per a importar ",
     "Primary CalDAV address" : "Adreça primària de caldav",
     "iOS/OS X CalDAV address" : "Adreça CalDAV per IOS/OS X"
 },
