@@ -97,14 +97,12 @@ OC.L10N.register(
     "More" : "Mere",
     "Edit" : "Redigér",
     "Link" : "Link",
-    "WebCal URL" : "WebCal URL",
     "Download" : "Hent",
     "Share with users or groups" : "Del med brugere eller grupper",
     "can edit" : "kan redigere",
     "New Calendar" : "Ny kalender",
     "Name" : "Navn",
     "New Subscription" : "Tilføj abonnement",
-    "WebCal-URL" : "WebCal-URL",
     "Edit event" : "Rediger begivenhed",
     "Delete Event" : "Slet begivenhed",
     "Save Event" : "Gem begivenhed",
@@ -131,7 +129,6 @@ OC.L10N.register(
     "The file contains objects incompatible with the selected calendar" : "Filen indeholder objekter som ikke er kompatible med den valgte kalender",
     "New calendar" : "Ny kalender",
     "Import scheduled" : "Importering planlagt",
-    "Settings" : "Indstillinger",
     "Skip simple event editor" : "Spring over enkel begivenheds tekstbehandler",
     "Show week numbers" : "Vis ugenummer ",
     "Import calendar" : "Importer kalender",
