@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
+    "%s has published the calendar \"%s\"" : "%s ha pubblicato il calendario \"%s\"",
     "Too many redirects. Aborting ..." : "Troppe redirezioni. Interruzione in corso...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Il server remoto ha negato l'accesso al calendario (errore HTTP {%s})",
     "Error connecting to remote server" : "Errore durante la connessione al server remoto",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Errore durante la richiesta di una risorsa al server remoto. Ciò potrebbe essere dovuto da una mancata corrispondenza del certificato",
     "Error requesting resource on remote server" : "Errore durante la richiesta di una risorsa al server remoto",
-    "%s has published the calendar \"%s\"" : "%s ha pubblicato il calendario \"%s\"",
     "Individual" : "Singolo",
     "Group" : "Gruppo",
     "Resource" : "Risorsa",
@@ -118,7 +118,7 @@ OC.L10N.register(
     "More" : "Altro",
     "Edit" : "Modifica",
     "Link" : "Collegamento",
-    "WebCal URL" : "URL WebCal",
+    "iCal link" : "Collegamento iCal",
     "Download" : "Scarica",
     "Share with users or groups" : "Condividi con utenti o gruppi",
     "can edit" : "può modificare",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "New Calendar" : "Nuovo calendario",
     "Name" : "Nome",
     "New Subscription" : "Nuova sottoscrizione",
-    "WebCal-URL" : "URL WebCal",
     "Go back" : "Indietro",
     "Go forward" : "Avanti",
     "Edit event" : "Modifica evento",
@@ -159,7 +158,7 @@ OC.L10N.register(
     "New calendar" : "Nuovo calendario",
     "File is empty" : "Il file è vuoto",
     "Import scheduled" : "Importa pianificati",
-    "Settings" : "Impostazioni",
+    "Subscribe & embed" : "Sottoscrivi e integra",
     "Publish URL" : "Pubblica URL",
     "Iframe to integrate" : "Iframe da integrare",
     "Settings & import" : "Impostazioni e importazione",
