@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendorius",
+    "%s has published the calendar \"%s\"" : "%s buvo paskelbta kalendoriuje \"%s\"",
     "Too many redirects. Aborting ..." : "Per daug nukreipimų. Nutraukiama ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Nutolęs serveris neleido prisijungti prie kalendoriaus (HTTP {%s} klaida)",
     "Error connecting to remote server" : "Klaida, jungiantis prie nuotolinio serverio",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Klaida gaunant informaciją iš nutolusio serverio. Tai galimai gali būti susiję su sertifikatų neatitikimu",
     "Error requesting resource on remote server" : "Klaida gaunant informaciją iš nutolusio serverio",
-    "%s has published the calendar \"%s\"" : "%s buvo paskelbta kalendoriuje \"%s\"",
     "Individual" : "Individualus",
     "Group" : "Grupė",
     "Resource" : "Išteklis",
@@ -34,7 +34,7 @@ OC.L10N.register(
     "When shared show only busy" : "Dalijantis rodyti kaip užimtą",
     "When shared hide this event" : "Dalijantis nerodyti šio įvykio",
     "Confirmed" : "Patvirtintas",
-    "Cancelled" : "Atšauktas",
+    "Cancelled" : "Atsisakyta",
     "Please add a title!" : "Pridėkite pavadinimą!",
     "Please select a calendar!" : "Pasirinkite kalendorių!",
     "Global" : "Globalus",
@@ -88,7 +88,7 @@ OC.L10N.register(
     "ends" : "baigiasi",
     "All day Event" : "Visos dienos įvykis",
     "Delete" : "Ištrinti",
-    "Cancel" : "Atšaukti",
+    "Cancel" : "Atsisakyti",
     "More ..." : "Daugiau...",
     "Create" : "Sukurti",
     "Update" : "Atnaujinti",
@@ -111,13 +111,13 @@ OC.L10N.register(
     "Week" : "Savaitė",
     "Month" : "Mėnuo",
     "Today" : "Šiandien",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Kai kurie kalendoriaus įvykiai yra sugadinti. Prašome patikrinti JS konsolę.",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Kai kurie šio kalendoriaus įvykiai yra sugadinti. Prašome patikrinti JS pultą.",
     "Share Calendar" : "Dalintis kalendoriumi",
     "Shared" : "Dalinamasi",
     "More" : "Daugiau",
     "Edit" : "Redaguoti",
     "Link" : "Nuoroda",
-    "WebCal URL" : "WebCal adresas",
+    "iCal link" : "iCal nuoroda",
     "Download" : "Atsisiųsti",
     "Share with users or groups" : "Dalintis su naudotojais arba grupėmis",
     "can edit" : "gali redaguoti",
@@ -128,7 +128,6 @@ OC.L10N.register(
     "New Calendar" : "Naujas kalendorius",
     "Name" : "Pavadinimas",
     "New Subscription" : "Nauja prenumerata",
-    "WebCal-URL" : "WebCal adresas",
     "Go back" : "Atgal",
     "Go forward" : "Pirmyn",
     "Edit event" : "Redaguoti įvykį",
@@ -152,16 +151,16 @@ OC.L10N.register(
     "end repeat ..." : "nutraukti pasikartojimą...",
     "times" : "kartus",
     "Import Calendars" : "Importuoti kalendorius",
-    "Import canceled" : "Importavimas atšauktas",
+    "Import canceled" : "Importavimo atsisakyta",
     "Analyzing calendar" : "Analizuojamas kalendorius",
     "The file contains objects incompatible with the selected calendar" : "Failas turi objektų kurie nėra suderinami su pasirinktu kalendoriumi",
     "New calendar" : "Naujas kalendorius",
     "File is empty" : "Failas tuščias",
     "Import scheduled" : "Importavimas suplanuotas",
-    "Settings" : "Nustatymai",
+    "Subscribe & embed" : "Prenumeruoti ir įdėti",
     "Publish URL" : "Skelbti adresą",
     "Iframe to integrate" : "Iframe integravimas",
-    "Settings & import" : "Nustatymai ir įkėlimas",
+    "Settings & import" : "Nustatymai ir importavimas",
     "Skip simple event editor" : "Praleisti paprastą įvykių redaktorių",
     "Show week numbers" : "Rodyti savaičių numerius",
     "Import calendar" : "Importuoti kalendorių",
