@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendário",
+    "%s has published the calendar \"%s\"" : "%s publicou o calendário \"%s\"",
     "Too many redirects. Aborting ..." : "Muitos redirecionamentos. Abortando...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "O servidor remoto não nos deu acesso ao calendário (erro HTTP {%s})",
     "Error connecting to remote server" : "Erro ao conectar ao servidor remoto",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erro ao solicitar recurso no servidor remoto. Isso poderia estar relacionado a uma incompatibilidade de certificado",
     "Error requesting resource on remote server" : "Erro ao solicitar recurso no servidor remoto",
-    "%s has published the calendar \"%s\"" : "%s publicou o calendário \"%s\"",
     "Individual" : "Individual",
     "Group" : "Grupo",
     "Resource" : "Recurso",
@@ -118,7 +118,7 @@ OC.L10N.register(
     "More" : "Mais",
     "Edit" : "Editar",
     "Link" : "Link",
-    "WebCal URL" : "WebCal URL",
+    "iCal link" : "Link do iCal",
     "Download" : "Baixar",
     "Share with users or groups" : "Compartilhar com usuários ou grupos",
     "can edit" : "pode editar",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "New Calendar" : "Novo Calendário",
     "Name" : "Nome",
     "New Subscription" : "Nova Subscrição",
-    "WebCal-URL" : "WebCal-URL",
     "Go back" : "Voltar",
     "Go forward" : "Avançar",
     "Edit event" : "Editar evento",
@@ -159,7 +158,7 @@ OC.L10N.register(
     "New calendar" : "Novo calendário",
     "File is empty" : "Arquivo em branco",
     "Import scheduled" : "Importar agendados",
-    "Settings" : "Configurações",
+    "Subscribe & embed" : "Subscrever & incorporar",
     "Publish URL" : "Publicar URL",
     "Iframe to integrate" : "frame para integrar",
     "Settings & import" : "Configurações & Importação",
