@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
+    "%s has published the calendar \"%s\"" : "%s har publicerat kalendern \"%s\"",
     "Too many redirects. Aborting ..." : "För många omdirigeringar. Avbryter ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Externa servern gav inte åtkomst när vi försökte ansluta till kalendern (HTTP {%s} error)",
     "Error connecting to remote server" : "Ett fel uppstod med anslutningen till extern delning",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Ett fel uppstod när en resurs på externa servern skulle begäras. Detta kan vara relaterat till ett certifikat som inte matchar",
     "Error requesting resource on remote server" : "Ett fel uppstod när en resurs på externa servern skulle begäras ",
-    "%s has published the calendar \"%s\"" : "%s har publicerat kalendern \"%s\"",
     "Individual" : "Individuell",
     "Group" : "Grupp",
     "Resource" : "Resurs",
@@ -19,7 +19,7 @@ OC.L10N.register(
     "{name} ({email})" : "{name} ({email})",
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Du är i en okänd tidszon ({tz}), faller tillbaka på UTC",
     "Please create a calendar first." : "Vänlligen skapa en kalender först.",
-    "New event" : "Nytt event",
+    "New event" : "Ny händelse",
     "CalDAV address for clients" : "CalDAV adress för klienter",
     "Error saving WebCal-calendar" : "Ett fel uppstod när WebCal-kalendern sparades",
     "WebDAV address for subscriptions" : "WebDAV-adress för prenumerationer",
@@ -118,7 +118,6 @@ OC.L10N.register(
     "More" : "Mer",
     "Edit" : "Ändra",
     "Link" : "Länk",
-    "WebCal URL" : "WebCal URL",
     "Download" : "Ladda ned",
     "Share with users or groups" : "Dela med användare eller grupper",
     "can edit" : "kan redigera",
@@ -129,7 +128,6 @@ OC.L10N.register(
     "New Calendar" : "Ny kalender",
     "Name" : "Namn",
     "New Subscription" : "Ny prenumeration",
-    "WebCal-URL" : "WebCal-URL",
     "Go back" : "Gå framåt",
     "Go forward" : "Gå bakåt",
     "Edit event" : "Redigera händelse",
@@ -159,7 +157,6 @@ OC.L10N.register(
     "New calendar" : "Ny kalender",
     "File is empty" : "Filen är tom",
     "Import scheduled" : "Import schemalagd",
-    "Settings" : "Inställningar",
     "Publish URL" : "Publicera URL",
     "Iframe to integrate" : "Iframe att integrera ",
     "Settings & import" : "Inställningar & import",
